==> synfigstudio_0.61.05.orig.tar.gz: synfigstudio-0.61.05/src/synfigapp/actions/groupaddlayers.h <==
/* === S Y N F I G ========================================================= */
/*!	\file action_groupaddlayers.h
**	\brief Template File
**
**	$Id: groupaddlayers.h,v 1.1.1.1 2005/01/07 03:34:37 darco Exp $
**
**	\legal
**	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
**
**	This package is free software; you can redistribute it and/or
**	modify it under the terms of the GNU General Public License as
**	published by the Free Software Foundation; either version 2 of
**	the License, or (at your option) any later version.
**
**	This package is distributed in the hope that it will be useful,
**	but WITHOUT ANY WARRANTY; without even the implied warranty of
**	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
**	General Public License for more details.
**	\endlegal
*/
/* ========================================================================= */

/* === S T A R T =========================================================== */

#ifndef __SYNFIG_APP_ACTION_GROUPADDLAYERS_H
#define __SYNFIG_APP_ACTION_GROUPADDLAYERS_H

/* === H E A D E R S ======================================================= */

#include <synfig/layer.h>
#include <synfigapp/action.h>
#include <list>

/* === M A C R O S ========================================================= */

/* === T Y P E D E F S ===================================================== */

/* === C L A S S E S & S T R U C T S ======================================= */

namespace synfigapp {

class Instance;

namespace Action {

class GroupAddLayers :
	public Undoable,
	public CanvasSpecific
{
private:

	// List contains the layers and their previous groups
	std::list<std::pair<synfig::Layer::Handle,synfig::String> > layer_list;
	
	// The name of the new group
	synfig::String group;

public:

	GroupAddLayers();

	static ParamVocab get_param_vocab();
	static bool is_canidate(const ParamList &x);

	virtual bool set_param(const synfig::String& name, const Param &);
	virtual bool is_ready()const;

	virtual void perform();
	virtual void undo();

	ACTION_MODULE_EXT
};

}; // END of namespace action
}; // END of namespace studio

/* === E N D =============================================================== */

#endif

==> synfigstudio_0.61.08.orig.tar.gz: synfigstudio-0.61.08/src/synfigapp/actions/groupaddlayers.h <==
/* === S Y N F I G ========================================================= */
/*!	\file groupaddlayers.h
**	\brief Template File
**
**	$Id: groupaddlayers.h 336 2007-03-16 00:39:42Z dooglus $
**
**	\legal
**	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
**
**	This package is free software; you can redistribute it and/or
**	modify it under the terms of the GNU General Public License as
**	published by the Free Software Foundation; either version 2 of
**	the License, or (at your option) any later version.
**
**	This package is distributed in the hope that it will be useful,
**	but WITHOUT ANY WARRANTY; without even the implied warranty of
**	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
**	General Public License for more details.
**	\endlegal
*/
/* ========================================================================= */

/* === S T A R T =========================================================== */

#ifndef __SYNFIG_APP_ACTION_GROUPADDLAYERS_H
#define __SYNFIG_APP_ACTION_GROUPADDLAYERS_H

/* === H E A D E R S ======================================================= */

#include <synfig/layer.h>
#include <synfigapp/action.h>
#include <list>

/* === M A C R O S ========================================================= */

/* === T Y P E D E F S ===================================================== */

/* === C L A S S E S & S T R U C T S ======================================= */

namespace synfigapp {

class Instance;

namespace Action {

class GroupAddLayers :
	public Undoable,
	public CanvasSpecific
{
private:

	// List contains the layers and their previous groups
	std::list<std::pair<synfig::Layer::Handle,synfig::String> > layer_list;

	// The name of the new group
	synfig::String group;

public:

	GroupAddLayers();

	static ParamVocab get_param_vocab();
	static bool is_candidate(const ParamList &x);

	virtual bool set_param(const synfig::String& name, const Param &);
	virtual bool is_ready()const;

	virtual void perform();
	virtual void undo();

	ACTION_MODULE_EXT
};

}; // END of namespace action
}; // END of namespace studio

/* === E N D =============================================================== */

#endif
